<script src="https://cdn.bootcss.com/Chart.js/2.1.6/Chart.bundle.js"></script>
<script type="text/javascript">

    var data = {
        labels: [
            "passed",
            "failed",
            "errors",
            "skiped",
        ],
        datasets: [
            {
                data: [{{ Pass }}, {{ fail }}, {{ error }}, {{ skip }}],
                backgroundColor: [
                    "#10c469",
                    "#f9c851",
                    "#ff5b5b",
                    "#98a6ad"
                ],
                hoverBackgroundColor: [
                    "#10c469",
                    "#f9c851",
                    "#ff5b5b",
                    "#98a6ad"
                ]
            }
        ]
    };
    var ctx = document.getElementById("myChart").getContext("2d");
    var myNewChart = new Chart(ctx, {
        type: 'doughnut',
        data: data,
        // options: options
    });

</script>